@@ -8,28 +8,33 @@ import tty
 
 if sys.version_info.major >= 3:
     # For mypy PEP-484 static typing validation
-    from six import text_type    # NOQA
-    from typing import List      # NOQA
-    from typing import Tuple     # NOQA
-    from typing import Union     # NOQA
+    from six import text_type  # NOQA
+    from typing import Dict  # NOQA
+    from typing import List  # NOQA
+    from typing import Tuple  # NOQA
     from typing import Optional  # NOQA
     from typing import Iterable  # NOQA
-    from . import px_process     # NOQA
+    from . import px_process  # NOQA
 
 
+# NOTE: To work with this list it can be useful to find the text "Uncomment to
+# debug input characters" in handle_search_keypresses() in px_top.py.
 KEY_ESC = "\x1b"
-KEY_BACKSPACE = "\x1b[3~"
-KEY_DELETE = "\x7f"
+KEY_DELETE = "\x1b[3~"
+KEY_BACKSPACE = "\x7f"
 KEY_UPARROW = "\x1b[A"
 KEY_DOWNARROW = "\x1b[B"
 KEY_ENTER = "\x0d"
 
 
-initial_termios_attr = None  # type: Optional[List[Union[int, List[bytes]]]]
+initial_termios_attr = None
 
 
 CSI = "\x1b["
 
+CURSOR_TO_TOP_LEFT = CSI + u"H"
+CURSOR_TO_RIGHT_EDGE = CSI + u"999C"  # Actually "999 steps to the right"
+
 """
 Clear the screen and move cursor to top left corner:
 https://en.wikipedia.org/wiki/ANSI_escape_code
@@ -40,14 +45,13 @@ for example, the contents of the previous screen gets added to the
 scrollback buffer, which isn't what we want. Tread carefully if you
 intend to change these.
 """
-CLEAR_SCREEN = CSI + u"1J" + CSI + u"H"
+CLEAR_SCREEN = CSI + u"1J" + CURSOR_TO_TOP_LEFT
 
-# Actually this is "Move 998 down and 999 right", but as long as people's
-# terminal windows are smaller than that it will work fine.
-#
-# Inspired by: https://stackoverflow.com/a/53168713/473672
-CURSOR_TO_BOTTOM_RIGHT = CSI + u"998B" + CSI + u"999C"
+HIDE_CURSOR = CSI + u"?25l"
+SHOW_CURSOR = CSI + u"?25h"
 
+CLEAR_TO_EOL = CSI + u"0K"
+CLEAR_TO_END_OF_SCREEN = CSI + "J"  # Clear from cursor to end of screen
 
 # Used for informing our getch() function that a window resize has occured
 SIGWINCH_PIPE = os.pipe()
@@ -55,22 +59,26 @@ SIGWINCH_PIPE = os.pipe()
 # We'll report window resize as this key having been pressed.
 #
 # NOTE: This must be detected as non-printable by handle_search_keypress().
-SIGWINCH_KEY = u'\x00'
+SIGWINCH_KEY = u"\x00"
 
 _enable_color = True
 
+previous_screen_lines = []  # type: List[text_type]
+previous_screen_columns = 0  # type: int
+
+
 def disable_color():
     global _enable_color
     _enable_color = False
 
+
 def sigwinch_handler(signum, frame):
     """Handle window resize signals by telling our getch() function to return"""
     # "r" for "refresh" perhaps? The actual letter doesn't matter, as long as it
     # doesn't collide with anything with some meaning other than "please
     # redraw".
-    os.write(
-        SIGWINCH_PIPE[1],
-        SIGWINCH_KEY.encode("utf-8"))
+    os.write(SIGWINCH_PIPE[1], SIGWINCH_KEY.encode("utf-8"))
+
 
 # Subscribe to window size change signals
 signal.signal(signal.SIGWINCH, sigwinch_handler)
@@ -89,13 +97,13 @@ class ConsumableString(object):
         if not self._string.startswith(to_consume):
             return False
 
-        self._string = self._string[len(to_consume):]
+        self._string = self._string[len(to_consume) :]
         return True
 
 
 def read_select(
     fds,  # type: List[int]
-    timeout_seconds=None  # type: Optional[int]
+    timeout_seconds=None,  # type: Optional[int]
 ):
     # type: (...) -> List[int]
     """Select on any of the fds becoming ready for read, retry on EINTR"""
@@ -135,8 +143,7 @@ def getch(timeout_seconds=None, fd=None):
     if fd is None:
         fd = sys.stdin.fileno()
 
-    can_read_from = (
-        read_select([fd, SIGWINCH_PIPE[0]], timeout_seconds))
+    can_read_from = read_select([fd, SIGWINCH_PIPE[0]], timeout_seconds)
 
     # Read all(ish) bytes from the first ready-for-read stream. If more than one
     # stream is ready, we'll catch the second one on the next call to this
@@ -170,7 +177,7 @@ def get_window_size():
         raise TerminalError("Not a TTY, window size not available")
 
     result = None
-    with os.popen('stty size', 'r') as stty_size:
+    with os.popen("stty size", "r") as stty_size:
         result = stty_size.read().split()
     if len(result) < 2:
         # Getting the terminal window width failed, don't truncate
@@ -191,39 +198,125 @@ def get_window_size():
     return (rows, columns)
 
 
-def draw_screen_lines(lines, clear=True):
-    # type: (List[text_type], bool) -> None
+def raw_lines_to_screen_lines(raw_lines, columns):
+    # type: (List[text_type], int) -> List[text_type]
+    """Crop the lines to the right length and add clear-to-EOL at the end"""
+    screen_lines = []  # type: List[text_type]
 
-    # We need both \r and \n when the TTY is in tty.setraw() mode
-    linestring = u"\r\n".join(lines)
+    for raw_line in raw_lines:
+        cooked = crop_ansi_string_at_length(raw_line, columns)
+        cooked += CLEAR_TO_EOL
+        screen_lines.append(cooked)
 
-    if clear:
-        screen_bytes = CLEAR_SCREEN + linestring
-    else:
-        screen_bytes = linestring
-
-    screen_bytes += CURSOR_TO_BOTTOM_RIGHT
-
-    os.write(sys.stdout.fileno(), screen_bytes.encode('utf-8'))
+    return screen_lines
 
 
-def to_screen_lines(procs,  # type: List[px_process.PxProcess]
-                    columns,  # type: Optional[int]
-                    row_to_highlight,  # type: Optional[int]
-                    highlight_heading  # type: Optional[text_type]
-                    ):
+def filter_out_unchanged_screen_lines(all_screen_lines, columns):
+    # type: (List[text_type], int) -> List[Optional[text_type]]
+    """Compare lines to the cache and None out the ones that match the cache"""
+    global previous_screen_lines
+    global previous_screen_columns
+
+    if len(previous_screen_lines) != len(all_screen_lines):
+        # Screen resized, never mind the cache
+        return all_screen_lines  # type: ignore
+    if previous_screen_columns != columns:
+        # Screen resized, never mind the cache
+        return all_screen_lines  # type: ignore
+
+    filtered = []  # type: List[Optional[text_type]]
+    for line_index, line in enumerate(all_screen_lines):
+        line_from_previous_screen = previous_screen_lines[line_index]
+        if line == line_from_previous_screen:
+            # Cache hit, don't draw this line
+            filtered.append(None)
+        else:
+            filtered.append(line)
+
+    return filtered
+
+
+def draw_screen_lines(lines, columns):
+    # type: (List[text_type], int) -> None
+
+    unfiltered_screen_lines = raw_lines_to_screen_lines(lines, columns)
+    screen_lines = filter_out_unchanged_screen_lines(unfiltered_screen_lines, columns)
+
+    screenstring = CURSOR_TO_TOP_LEFT
+    skip_lines = 0
+    for screen_line in screen_lines:
+        if screen_line is None:
+            skip_lines += 1
+        else:
+            if skip_lines > 0:
+                # Move down the required number of lines
+                screenstring += CSI + str(skip_lines) + "E"
+                skip_lines = 0
+
+            # The line changed, update it!
+            screenstring += screen_line
+
+            # Move to next line
+            skip_lines = 1
+
+    if skip_lines > 1:
+        # Move down the required number of lines. "- 1" because if we skip after
+        # the last line, there'll be a leftover line when we enter the
+        # per-process menu.
+        screenstring += CSI + str(skip_lines - 1) + "E"
+        skip_lines = 0
+
+    # Keep the cache up to date
+    global previous_screen_lines
+    global previous_screen_columns
+    previous_screen_lines = unfiltered_screen_lines
+    previous_screen_columns = columns
+
+    # In case we got fewer lines than what fits on screen, clear the rest of it.
+    # We must start at the right edge of screen doing this in case differential
+    # rendering made us not do anything for the last screen line.
+    screenstring += CURSOR_TO_RIGHT_EDGE + CLEAR_TO_END_OF_SCREEN
+
+    os.write(sys.stdout.fileno(), screenstring.encode("utf-8"))
+
+
+def width_specifier(width, right_align=False):
+    # type: (int, bool) -> text_type
+    return_me = u"{:"
+
+    if right_align:
+        return_me += u">"
+
+    return_me += str(width)
+    return_me += u"}"
+
+    return return_me
+
+
+def to_screen_lines(
+    procs,  # type: List[px_process.PxProcess]
+    row_to_highlight,  # type: Optional[int]
+    highlight_heading,  # type: Optional[text_type]
+    with_username=True,  # type: bool
+):
     # type: (...) -> List[text_type]
     """
-    Returns an array of lines that can be printed to screen. Each line is at
-    most columns wide.
-
-    If columns is None, line lengths are unbounded.
+    Returns an array of lines that can be printed to screen. Lines are not
+    cropped, so they can be longer than the screen width.
 
     If highligh_heading contains a column name, that column will be highlighted.
     The column name must be from the hard coded list in this function, see below.
     """
 
-    headings = [u"PID", u"COMMAND", u"USERNAME", u"CPU", u"CPUTIME", u"RAM", u"COMMANDLINE"]
+    headings = [
+        u"PID",
+        u"COMMAND",
+        u"USERNAME",
+        u"CPU",
+        u"CPUTIME",
+        u"RAM",
+        u"COMMANDLINE",
+    ]
     highlight_column = None  # type: Optional[int]
     if highlight_heading is not None:
         highlight_column = headings.index(highlight_heading)
@@ -243,37 +336,31 @@ def to_screen_lines(procs,  # type: List[px_process.PxProcess]
         cputime_width = max(cputime_width, len(proc.cpu_time_s))
         mem_width = max(mem_width, len(proc.memory_percent_s))
 
-    format = (
-        u'{:>' + str(pid_width) +
-        u'} {:' + str(command_width) +
-        u'} {:' + str(username_width) +
-        u'} {:>' + str(cpu_width) +
-        u'} {:>' + str(cputime_width) +
-        u'} {:>' + str(mem_width) + u'} {}')
+    format_specifiers = [
+        width_specifier(pid_width, right_align=True),
+        width_specifier(command_width),
+        width_specifier(username_width),
+        width_specifier(cpu_width, right_align=True),
+        width_specifier(cputime_width, right_align=True),
+        width_specifier(mem_width, right_align=True),
+        "{}",  # The command line can have any length
+    ]
+
+    if not with_username:
+        username_index = headings.index("USERNAME")
+        del headings[username_index]
+        del format_specifiers[username_index]
+
+    format = " ".join(format_specifiers)
 
     # Print process list using the computed column widths
     lines = []
 
-    heading_line = format.format(
-        headings[0], headings[1], headings[2], headings[3], headings[4], headings[5], headings[6])
-    heading_line_length = len(heading_line)
-    heading_line_delta = 0
-    if columns is not None:
-        heading_line_delta = columns - heading_line_length
-
     # Highlight the highlight_column
     if highlight_column is not None:
         headings[highlight_column] = underline(headings[highlight_column])
-    heading_line = format.format(
-        headings[0], headings[1], headings[2], headings[3], headings[4], headings[5], headings[6])
-
-    # Set heading line length
-    if heading_line_delta > 0:
-        heading_line += heading_line_delta * u' '
-    if heading_line_delta < 0:
-        new_length = heading_line_length + heading_line_delta
-        heading_line = crop_ansi_string_at_length(heading_line, new_length)
 
+    heading_line = format.format(*headings)
     heading_line = bold(heading_line)
     lines.append(heading_line)
 
@@ -311,18 +398,23 @@ def to_screen_lines(procs,  # type: List[px_process.PxProcess]
         if proc.cpu_time_s == max_cpu_time_s:
             cpu_time_s = bold(cpu_time_s.rjust(cputime_width))
 
-        line = format.format(
-            proc.pid, proc.command, proc.username,
-            cpu_percent_s, cpu_time_s,
-            memory_percent_s, proc.cmdline)
+        columns = [
+            str(proc.pid),
+            proc.command,
+            proc.username,
+            cpu_percent_s,
+            cpu_time_s,
+            memory_percent_s,
+            proc.cmdline,
+        ]
+        if not with_username:
+            del columns[username_index]
+        line = format.format(*columns)
 
-        cropped = line
         if row_to_highlight == line_number:
-            cropped = get_string_of_length(cropped, columns)
-            cropped = inverse_video(cropped)
-        elif columns is not None:
-            cropped = crop_ansi_string_at_length(line, columns)
-        lines.append(cropped)
+            # Highlight the whole screen line
+            line = inverse_video(line + u" " * 999)
+        lines.append(line)
 
     lines[0] = heading_line
 
@@ -395,7 +487,7 @@ def get_string_of_length(string, length):
         return string
 
     if initial_length < length:
-        return string + u' ' * (length - initial_length)
+        return string + u" " * (length - initial_length)
 
     if initial_length > length:
         return crop_ansi_string_at_length(string, length)
@@ -423,7 +515,7 @@ def _tokenize(string):
 
         # We are at a CSI marker
         try:
-            next_m_index = string.index('m', i)
+            next_m_index = string.index("m", i)
         except ValueError:
             # No end-of-escape sequence found
             break
@@ -438,11 +530,21 @@ def _tokenize(string):
     yield string[i:]
 
 
+crop_cache = {}  # type: Dict[Tuple[text_type, int], text_type]
+
+
 def crop_ansi_string_at_length(string, length):
     # type: (text_type, int) -> text_type
     assert length >= 0
-    if length == 0:
-        return ''
+
+    global crop_cache
+    cache_key = (string, length)
+    cache_hit = crop_cache.get(cache_key, None)
+    if cache_hit is not None:
+        return cache_hit
+    if len(crop_cache) > 400:
+        # LRU would be better but this is easier to implement
+        crop_cache.clear()
 
     result = u""
     char_count = 0
@@ -451,7 +553,7 @@ def crop_ansi_string_at_length(string, length):
 
     for token in _tokenize(string):
         if token.startswith(CSI):
-            reset_sequence = CSI + '0m'
+            reset_sequence = CSI + "0m"
             if token == reset_sequence:
                 # Already reset
                 reset_sequence = ""
@@ -467,7 +569,9 @@ def crop_ansi_string_at_length(string, length):
         result += token
         char_count += len(token)
 
-    return result + reset_sequence
+    cache_hit = result + reset_sequence
+    crop_cache[cache_key] = cache_hit
+    return cache_hit
 
 
 def visual_length(string):
@@ -484,6 +588,7 @@ def visual_length(string):
 
     return count
 
+
 def _enter_fullscreen():
     global initial_termios_attr
     assert initial_termios_attr is None
@@ -494,12 +599,16 @@ def _enter_fullscreen():
 
     tty.setraw(fd)
 
+    os.write(fd, HIDE_CURSOR.encode("utf-8"))
+
 
 def _exit_fullscreen():
     global initial_termios_attr
     assert initial_termios_attr is not None
 
     fd = sys.stdin.fileno()
+    os.write(fd, SHOW_CURSOR.encode("utf-8"))
+
     tty.setcbreak(fd)
 
     # tty.setraw() disables local echo, so we have to re-enable it here.
