@@ -7,21 +7,19 @@ import logging
 import unicodedata
 
 import os
-from . import px_load
 from . import px_process
 from . import px_terminal
-from . import px_meminfo
 from . import px_processinfo
-from . import px_launchcounter
 from . import px_process_menu
+from . import px_poller
 
-if False:
+if sys.version_info.major >= 3:
     # For mypy PEP-484 static typing validation
-    from typing import List      # NOQA
-    from typing import Dict      # NOQA
-    from typing import Union     # NOQA
+    from typing import List  # NOQA
+    from typing import Dict  # NOQA
+    from typing import Union  # NOQA
     from typing import Optional  # NOQA
-    from six import text_type    # NOQA
+    from six import text_type  # NOQA
 
 LOG = logging.getLogger(__name__)
 
@@ -29,6 +27,7 @@ CMD_WHATEVER = -1
 CMD_QUIT = 1
 CMD_RESIZE = 2
 CMD_HANDLED = 3
+CMD_POLL_COMPLETE = 4
 
 SEARCH_PROMPT_ACTIVE = px_terminal.inverse_video("Search (ENTER when done): ")
 SEARCH_PROMPT_INACTIVE = "Search ('/' to edit): "
@@ -38,7 +37,7 @@ MODE_BASE = 0
 MODE_SEARCH = 1
 
 top_mode = MODE_BASE  # type: int
-search_string = ""  # type: text_type
+search_string = u""
 
 # Which pid were we last hovering?
 last_highlighted_pid = None  # type: Optional[int]
@@ -51,9 +50,6 @@ last_highlighted_row = 0  # type: int
 # row even if the tow PID moves away.
 highlight_has_moved = False  # type: bool
 
-# When we last polled the system for a process list, in seconds since the Epoch
-last_process_poll = 0.0
-
 # Order top list by memory usage. The opposite is by CPU usage.
 sort_by_memory = False
 
@@ -96,7 +92,8 @@ def adjust_cpu_times(baseline, current):
         current_proc = copy.copy(current_proc)
         if current_proc.cpu_time_seconds and baseline_proc.cpu_time_seconds:
             current_proc.set_cpu_time_seconds(
-                current_proc.cpu_time_seconds - baseline_proc.cpu_time_seconds)
+                current_proc.cpu_time_seconds - baseline_proc.cpu_time_seconds
+            )
         pid2proc[current_proc.pid] = current_proc
 
     return list(pid2proc.values())
@@ -137,10 +134,11 @@ def sort_by_cpu_usage(toplist):
     return sorted(toplist, key=lambda process: process.cpu_percent or 0, reverse=True)
 
 
-def get_toplist(baseline,  # type: List[px_process.PxProcess]
-                current,   # type: List[px_process.PxProcess]
-                by_memory=False  # type: bool
-                ):
+def get_toplist(
+    baseline,  # type: List[px_process.PxProcess]
+    current,  # type: List[px_process.PxProcess]
+    by_memory=False,  # type: bool
+):
     # type(...) -> List[px_process.PxProcess]
     toplist = adjust_cpu_times(baseline, current)
 
@@ -190,7 +188,8 @@ def get_line_to_highlight(toplist, max_process_count):
 
     # Bound highlight to toplist length and screen height
     last_highlighted_row = min(
-        last_highlighted_row, max_process_count - 1, len(toplist) - 1)
+        last_highlighted_row, max_process_count - 1, len(toplist) - 1
+    )
     if last_highlighted_row < 0:
         last_highlighted_row = 0
 
@@ -204,51 +203,46 @@ def get_line_to_highlight(toplist, max_process_count):
 
 
 def get_screen_lines(
-    toplist,   # type: List[px_process.PxProcess]
-    launchcounter,  # type: px_launchcounter.Launchcounter
-    rows,      # type: int
-    columns,   # type: int
+    toplist,  # type: List[px_process.PxProcess]
+    poller,  # type: px_poller.PxPoller
+    rows,  # type: int
     include_footer=True,  # type: bool
     search=None,  # type: Optional[text_type]
 ):
     # type: (...) -> List[text_type]
 
-    if search is not None:
+    if search:
         # Note that we accept partial user name match, otherwise incrementally typing
         # a username becomes weird for the ptop user
-        toplist = list(filter(lambda p: p.match(search, require_exact_user=False), toplist))
+        toplist = list(
+            filter(lambda p: p.match(search, require_exact_user=False), toplist)
+        )
 
     # Hand out different amount of lines to the different sections
-    header_height = 3  # System load, RAM load, empty line
     footer_height = 0
     cputop_minheight = 10
     if include_footer:
         footer_height = 1
 
     # Print header
-    load = px_load.get_load_values()
-    loadstring = px_load.get_load_string(load)
-
-    meminfo = px_meminfo.get_meminfo()
     lines = [
-        px_terminal.crop_ansi_string_at_length(
-            px_terminal.bold(u"Sysload: ") + loadstring, columns),
-        px_terminal.crop_ansi_string_at_length(
-            px_terminal.bold(u"RAM Use: ") + meminfo, columns),
-        u""]
+        px_terminal.bold(u"Sysload: ") + poller.get_loadstring(),
+        px_terminal.bold(u"RAM Use: ") + poller.get_meminfo(),
+        px_terminal.bold(u"IO Load:      ") + poller.get_ioload_string(),
+        u"",
+    ]
 
     # Create a launchers section
+    header_height = len(lines)
     launches_maxheight = rows - header_height - cputop_minheight - footer_height
     launchlines = []  # type: List[text_type]
     if launches_maxheight >= 3:
-        launchlines = launchcounter.get_screen_lines(columns)
+        launchlines = poller.get_launchcounter_lines()
         if len(launchlines) > 0:
             # Add a section header
             launchlines = [
-                '',
-                px_terminal.crop_ansi_string_at_length(
-                    px_terminal.bold(
-                        "Launched binaries, launch counts in (parentheses)"), columns)
+                "",
+                px_terminal.bold("Launched binaries, launch counts in (parentheses)"),
             ] + launchlines
 
             # Cut if we got too many lines
@@ -271,20 +265,18 @@ def get_screen_lines(
     highlight_column = u"CPUTIME"
     if sort_by_memory:
         highlight_column = u"RAM"
-    toplist_table_lines = \
-        px_terminal.to_screen_lines(toplist, columns, highlight_row, highlight_column)
+    toplist_table_lines = px_terminal.to_screen_lines(
+        toplist[:max_process_count], highlight_row, highlight_column
+    )
 
     # Ensure that we cover the whole screen, even if it's higher than the
     # number of processes
-    toplist_table_lines += rows * ['']
+    toplist_table_lines += rows * [""]
 
     top_what = "CPU"
     if sort_by_memory:
         top_what = "memory"
-    lines += [
-        px_terminal.crop_ansi_string_at_length(
-            px_terminal.bold("Top " + top_what + " using processes"), columns)
-    ]
+    lines += [px_terminal.bold("Top " + top_what + " using processes")]
 
     if top_mode == MODE_SEARCH:
         lines += [SEARCH_PROMPT_ACTIVE + px_terminal.bold(search or "") + SEARCH_CURSOR]
@@ -292,15 +284,18 @@ def get_screen_lines(
         assert top_mode == MODE_BASE
         lines += [SEARCH_PROMPT_INACTIVE + px_terminal.bold(search or "")]
 
-    lines += toplist_table_lines[0:max_process_count + 1]  # +1 for the column headings
+    lines += toplist_table_lines[
+        0 : max_process_count + 1
+    ]  # +1 for the column headings
 
     lines += launchlines
 
     if include_footer:
-        footer_line = \
+        footer_line = (
             u"  q - Quit  m - Sort order  / - Search  ↑↓ - Move  Enter - Select"
-        footer_line = px_terminal.get_string_of_length(footer_line, columns)
-        footer_line = px_terminal.inverse_video(footer_line)
+        )
+        # Inverse the whole footer line
+        footer_line = px_terminal.inverse_video(footer_line + 999 * u" ")
 
         lines += [footer_line]
 
@@ -308,12 +303,11 @@ def get_screen_lines(
 
 
 def redraw(
-    toplist,   # type: List[px_process.PxProcess]
-    launchcounter,  # type: px_launchcounter.Launchcounter
-    rows,      # type: int
-    columns,   # type: int
-    clear=True,  # type: bool
-    include_footer=True  # type: bool
+    toplist,  # type: List[px_process.PxProcess]
+    poller,  # type: px_poller.PxPoller
+    rows,  # type: int
+    columns,  # type: int
+    include_footer=True,  # type: bool
 ):
     # type: (...) -> None
     """
@@ -323,10 +317,10 @@ def redraw(
     """
     global search_string
     lines = get_screen_lines(
-        toplist, launchcounter, rows, columns, include_footer,
-        search=search_string)
+        toplist, poller, rows, include_footer, search=search_string
+    )
 
-    px_terminal.draw_screen_lines(lines, clear)
+    px_terminal.draw_screen_lines(lines, columns)
 
 
 def handle_search_keypresses(key_sequence):
@@ -353,7 +347,10 @@ def handle_search_keypresses(key_sequence):
         elif key_sequence.consume(px_terminal.KEY_DOWNARROW):
             last_highlighted_row += 1
             last_highlighted_pid = None
-        elif key_sequence.consume(px_terminal.KEY_ENTER) or key_sequence._string == px_terminal.KEY_ESC:
+        elif (
+            key_sequence.consume(px_terminal.KEY_ENTER)
+            or key_sequence._string == px_terminal.KEY_ESC
+        ):
             # Exit search mode
             global top_mode
             top_mode = MODE_BASE
@@ -410,20 +407,24 @@ def get_command(**kwargs):
             if last_highlighted_pid is None:
                 continue
             processes = px_process.get_all()
-            process = px_processinfo.find_process_by_pid(last_highlighted_pid, processes)
+            process = px_processinfo.find_process_by_pid(
+                last_highlighted_pid, processes
+            )
             if not process:
                 continue
             px_process_menu.PxProcessMenu(process).start()
-        elif input.consume(u'/'):
+        elif input.consume(u"/"):
             global search_string
             top_mode = MODE_SEARCH
             return None
-        elif input.consume(u'm') or input.consume(u'M'):
+        elif input.consume(u"m") or input.consume(u"M"):
             sort_by_memory = not sort_by_memory
-        elif input.consume(u'q'):
+        elif input.consume(u"q"):
             return CMD_QUIT
         elif input.consume(px_terminal.SIGWINCH_KEY):
             return CMD_RESIZE
+        elif input.consume(px_poller.POLL_COMPLETE_KEY):
+            return CMD_POLL_COMPLETE
         else:
             # Unable to consume anything, give up
             break
@@ -437,43 +438,47 @@ def _top(search=""):
     global search_string
     search_string = search
 
-    baseline = px_process.get_all()
-    current = baseline
-    launchcounter = px_launchcounter.Launchcounter()
-    while True:
-        launchcounter.update(current)
-        rows, columns = px_terminal.get_window_size()
-        global sort_by_memory
-        toplist = get_toplist(baseline, current, sort_by_memory)
-        redraw(toplist, launchcounter, rows, columns)
+    poller = px_poller.PxPoller(px_terminal.SIGWINCH_PIPE[1])
+    poller.start()
 
-        command = get_command(timeout_seconds=1)
+    baseline = poller.get_all_processes()
+    current = poller.get_all_processes()
+
+    global sort_by_memory
+    toplist = get_toplist(baseline, current, sort_by_memory)
+
+    rows, columns = px_terminal.get_window_size()
+
+    while True:
+        redraw(toplist, poller, rows, columns)
+
+        command = get_command()
 
         # Handle all keypresses before refreshing the display
-        while command is not None:
+        if command is not None:
+            poller.pause_process_updates_a_bit()
             if command == CMD_QUIT:
                 # The idea here is that if you terminate with "q" you still
                 # probably want the heading line on screen. So just do another
                 # update with somewhat fewer lines, and you'll get just that.
-                redraw(toplist, launchcounter, rows - 4, columns, include_footer=False)
+                redraw(toplist, poller, rows - 4, columns, include_footer=False)
                 return
 
-            command = get_command(timeout_seconds=0)
+            if command == CMD_RESIZE:
+                rows, columns = px_terminal.get_window_size()
 
-        # For interactivity reasons, don't do this too often
-        global last_process_poll
-        now = time.time()
-        delta_seconds = now - last_process_poll
-        if delta_seconds >= 0.8:
-            current = px_process.get_all()
-            last_process_poll = now
+            if command == CMD_POLL_COMPLETE:
+                current = poller.get_all_processes()
+                toplist = get_toplist(baseline, current, sort_by_memory)
 
 
 def top(search=""):
     # type: (str) -> None
 
     if not sys.stdout.isatty():
-        sys.stderr.write('Top mode only works on TTYs, try running just "px" instead.\n')
+        sys.stderr.write(
+            'Top mode only works on TTYs, try running just "px" instead.\n'
+        )
         exit(1)
 
     with px_terminal.fullscreen_display():
