@@ -13,10 +13,14 @@ def test_averages_to_levels():
     # 1: 1/6 - 3/6
     # 2: 3/6 - 5/6
     # 3: 5/6 - 6/6
-    l0, l1, l2, peak = px_load.averages_to_levels(1.0 / 6.0 - 0.01, 1.0 / 6.0 + 0.01, 1.0)
+    l0, l1, l2, peak = px_load.averages_to_levels(
+        1.0 / 6.0 - 0.01, 1.0 / 6.0 + 0.01, 1.0
+    )
     assert (l0, l1, l2, peak) == (0, 1, 3, 1.0)
 
-    l0, l1, l2, peak = px_load.averages_to_levels(5.0 / 6.0 - 0.01, 5.0 / 6.0 + 0.01, 1.0)
+    l0, l1, l2, peak = px_load.averages_to_levels(
+        5.0 / 6.0 - 0.01, 5.0 / 6.0 + 0.01, 1.0
+    )
     assert (l0, l1, l2, peak) == (2, 3, 3, 1.0)
 
 
@@ -37,6 +41,7 @@ def test_levels_to_graph():
 
 
 def test_get_load_string():
+    px_terminal._enable_color = True
     CSI = u"\x1b["
     assert "0.3" + CSI in px_load.get_load_string((0.3, 0.2, 0.1))
     assert "3.0" + CSI in px_load.get_load_string((3.0, 0.2, 0.1))
