@@ -1,4 +1,5 @@
 import re
+import os
 import random
 import datetime
 
@@ -10,17 +11,27 @@ import dateutil.tz
 import dateutil.parser
 
 import sys
+
 if sys.version_info.major >= 3:
     # For mypy PEP-484 static typing validation
     from typing import MutableMapping  # NOQA
-    from typing import Optional        # NOQA
-    from typing import List            # NOQA
+    from typing import Optional  # NOQA
+    from typing import List  # NOQA
+    from six import text_type  # NOQA
 
 # An example time string that can be produced by ps
 TIMESTRING = "Mon Mar  7 09:33:11 2016"
 TIME = dateutil.parser.parse(TIMESTRING).replace(tzinfo=dateutil.tz.tzlocal())
 
 
+def load(sample_file_name):
+    # type: (text_type) -> text_type
+    my_dir = os.path.dirname(__file__)
+    full_path = os.path.join(my_dir, sample_file_name)
+    with open(full_path) as sample_file:
+        return sample_file.read()
+
+
 def spaces(at_least=1, at_most=3):
     return " " * random.randint(at_least, at_most)
 
@@ -29,40 +40,54 @@ def now():
     return datetime.datetime.now().replace(tzinfo=dateutil.tz.tzlocal())
 
 
-def create_process(pid=47536, ppid=1234,
-                   timestring=TIMESTRING,
-                   uid=0,
-                   cpuusage="0.0",
-                   cputime="0:00.03", mempercent="0.0",
-                   commandline="/usr/sbin/cupsd -l",
-                   now=now()):
+def create_process(
+    pid=47536,
+    ppid=1234,
+    timestring=TIMESTRING,
+    uid=0,
+    cpuusage="0.0",
+    cputime="0:00.03",
+    mempercent="0.0",
+    commandline="/usr/sbin/cupsd -l",
+    now=now(),
+):
     # type: (...) -> px_process.PxProcess
-    psline = (spaces(at_least=0) +
-              str(pid) + spaces() +
-              str(ppid) + spaces() +
-              timestring + spaces() +
-              str(uid) + spaces() +
-              cpuusage + spaces() +
-              cputime + spaces() +
-              mempercent + spaces() +
-              commandline)
+    psline = (
+        spaces(at_least=0)
+        + str(pid)
+        + spaces()
+        + str(ppid)
+        + spaces()
+        + timestring
+        + spaces()
+        + str(uid)
+        + spaces()
+        + cpuusage
+        + spaces()
+        + cputime
+        + spaces()
+        + mempercent
+        + spaces()
+        + commandline
+    )
 
     return px_process.ps_line_to_process(psline, now)
 
 
-def create_file(filetype,     # type: str
-                name,         # type: str
-                device,       # type: Optional[str]
-                pid,          # type: int
-                access=None,  # type: str
-                inode=None,   # type: str
-                fd=None,      # type: int
-                fdtype=None,  # type: Optional[str]
-                ):
+def create_file(
+    filetype,  # type: str
+    name,  # type: str
+    device,  # type: Optional[str]
+    pid,  # type: int
+    access=None,  # type: str
+    inode=None,  # type: str
+    fd=None,  # type: int
+    fdtype=None,  # type: Optional[str]
+):
     # type (...) -> px_file.PxFile
 
     # Remove leading [] group from name if any
-    match = re.match(r'(\[[^]]*\] )?(.*)', name)
+    match = re.match(r"(\[[^]]*\] )?(.*)", name)
     assert match
     name = match.group(2)
 
